@@ -121,9 +121,16 @@ class Gateway():
                         _LOGGER.exception ("error communicating...: " + str(e1))
         
 
-
-
     def executeCommand(self, command):
+        a = CommeoServiceGetState()
+        self._executeCommand(a)
+        _LOGGER.debug("Service State: " + str(a.status))
+        if a.status == ServiceState.READY:
+            self._executeCommand(command)
+        else:
+            _LOGGER.error("Gateway not ready to execute command")
+
+    def _executeCommand(self, command):
         """[summary]
         Execute the given command using the serial port.
         It opens a communication to the serial port each time a
@@ -159,7 +166,8 @@ class Gateway():
                     if (response.decode() == ''):
                         break
                     
-                _LOGGER.debug('read data: ' + response_str)
+                _LOGGER.debug('read data: ' + response_str)            
+                self.ser.close()
                 return process_response(response_str)
                         
             except Exception as e:
