@@ -272,19 +272,6 @@ class ActorDevice(Device):
         else:
             self.executeCommand(CommandType.AUTOOFF, type)
 
-    def scanStart(self):
-        commandStart = CommeoDeviceScanStart()
-        commandResult = CommeoDeviceScanResult()
-        commandStart.execute(self.gateway)
-        commandResult.execute(self.gateway)
-        while commandResult.scanState == ScanState.RUN or commandResult.scanState == ScanState.VERIFY:
-            wait(commandResult.timeLeft+1)
-            commandResult.execute(self.gateway)
-        if commandResult.scanState == ScanState.END_SUCCESS:
-            if commandResult.noNewDevices > 0:
-                return commandResult.foundIds
-        return {}
-
     def saveDevice(self):
         command = CommeoDeviceSave(self.ID)
         command.execute(self.gateway)
